"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const compute_root_paths_1 = require("./compute-root-paths");
describe('routeMatch', () => {
    let env = {
        emulator: 'true',
        project: 'adminjs-app',
        region: 'us-east-1',
        target: 'admin',
    };
    let options;
    let customFunctionPath;
    beforeEach(() => {
        env = {
            emulator: 'true',
            project: 'adminjs-app',
            region: 'us-east-1',
            target: 'admin',
        };
        options = {
            rootPath: '/admin',
            loginPath: '/admin/login',
            logoutPath: '/admin/logout',
        };
        customFunctionPath = undefined;
    });
    context('run on localhost', () => {
        let functionLocalPath;
        beforeEach(() => {
            env.emulator = 'true';
            functionLocalPath = compute_root_paths_1.getLocalhostPathForEnv(env);
        });
        it('fixes root admin paths that they have function url', () => {
            const paths = compute_root_paths_1.computeRootPaths(options, env, customFunctionPath);
            chai_1.expect(paths.rootPath).to.equal(`/${functionLocalPath}/admin`);
            chai_1.expect(paths.loginPath).to.equal(`/${functionLocalPath}/admin/login`);
            chai_1.expect(paths.logoutPath).to.equal(`/${functionLocalPath}/admin/logout`);
        });
        it('it is not affected by customFunctionPath', () => {
            const paths = compute_root_paths_1.computeRootPaths(options, env, 'customDomain');
            chai_1.expect(paths.rootPath).to.equal(`/${functionLocalPath}/admin`);
            chai_1.expect(paths.loginPath).to.equal(`/${functionLocalPath}/admin/login`);
            chai_1.expect(paths.logoutPath).to.equal(`/${functionLocalPath}/admin/logout`);
        });
        it('works when adminRoot is set to "/"', () => {
            options = {
                rootPath: '/',
                loginPath: '/login',
                logoutPath: '/logout',
            };
            const paths = compute_root_paths_1.computeRootPaths(options, env);
            chai_1.expect(paths.rootPath).to.equal(`/${functionLocalPath}`);
            chai_1.expect(paths.loginPath).to.equal(`/${functionLocalPath}/login`);
            chai_1.expect(paths.logoutPath).to.equal(`/${functionLocalPath}/logout`);
        });
    });
    context('run on default host without custom domain', () => {
        beforeEach(() => {
            env.emulator = undefined;
            customFunctionPath = undefined;
        });
        it('changes urls by adding the target domain', () => {
            const paths = compute_root_paths_1.computeRootPaths(options, env);
            chai_1.expect(paths.rootPath).to.equal(`/${env.target}/admin`);
            chai_1.expect(paths.loginPath).to.equal(`/${env.target}/admin/login`);
            chai_1.expect(paths.logoutPath).to.equal(`/${env.target}/admin/logout`);
        });
        it('works when adminRoot is set to "/"', () => {
            options = {
                rootPath: '/',
                loginPath: '/login',
                logoutPath: '/logout',
            };
            const paths = compute_root_paths_1.computeRootPaths(options, env);
            chai_1.expect(paths.rootPath).to.equal(`/${env.target}`);
            chai_1.expect(paths.loginPath).to.equal(`/${env.target}/login`);
            chai_1.expect(paths.logoutPath).to.equal(`/${env.target}/logout`);
        });
    });
    context('run on host with custom domain', () => {
        beforeEach(() => {
            env.emulator = undefined;
            customFunctionPath = 'app';
        });
        it('changes urls by adding the target domain', () => {
            const paths = compute_root_paths_1.computeRootPaths(options, env, customFunctionPath);
            chai_1.expect(paths.rootPath).to.equal(`/${customFunctionPath}/admin`);
            chai_1.expect(paths.loginPath).to.equal(`/${customFunctionPath}/admin/login`);
            chai_1.expect(paths.logoutPath).to.equal(`/${customFunctionPath}/admin/logout`);
        });
        it('works when adminRoot is set to "/"', () => {
            options = {
                rootPath: '/',
                loginPath: '/login',
                logoutPath: '/logout',
            };
            const paths = compute_root_paths_1.computeRootPaths(options, env, customFunctionPath);
            chai_1.expect(paths.rootPath).to.equal(`/${customFunctionPath}`);
            chai_1.expect(paths.loginPath).to.equal(`/${customFunctionPath}/login`);
            chai_1.expect(paths.logoutPath).to.equal(`/${customFunctionPath}/logout`);
        });
    });
});
